package com.tanpu.community.manager;

import com.tanpu.common.auth.UserHolder;
import com.tanpu.common.exception.BizException;
import com.tanpu.community.api.beans.qo.TopicRankQo;
import com.tanpu.community.api.beans.req.page.Page;
import com.tanpu.community.api.beans.req.topic.TopicSearchReq;
import com.tanpu.community.api.enums.VisitTypeEnum;
import com.tanpu.community.service.*;
import com.tanpu.community.util.PageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

@Service
public class TopicManager {

    @Autowired
    private TopicService topicService;

    @Autowired
    private VisitSummaryService visitSummaryService;
    @Autowired
    private RankService rankService;

    @Resource
    private UserHolder userHolder;

    // 新增话题
    public void insertTopic(String topicTitle, String userId) {
        if (topicService.queryByTitile(topicTitle) != null) {
            throw new BizException("话题名称已存在:" + topicTitle);
        }
        topicService.addTopic(topicTitle, userId);

    }

    // 首页-话题标签
    public List<TopicRankQo> getTop4TopicTitles() {
        return rankService.getRankTopicListTop4();
    }


    // 话题搜索列表
    public Page<TopicRankQo> getAllTopicBriefInfo(TopicSearchReq req) {

        List<TopicRankQo> topicList = rankService.getRankTopicList(req.getSearchKeyword());
        return PageUtils.page(req.getPage(), topicList);
    }

    // 话题详情页
    public TopicRankQo getDetail(String topicId) {
        return rankService.getTopicDetail(topicId);
    }


}

